@@ -10,7 +10,7 @@
  *
  *  ---------------------------------------------------------------------
  *  
- *  Copyright (c) 2010-2013 The MathJax Consortium
+ *  Copyright (c) 2010-2014 The MathJax Consortium
  * 
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -26,7 +26,7 @@
  */
 
 MathJax.Hub.Register.LoadHook("[MathJax]/jax/element/mml/jax.js",function () {
-  var VERSION = "2.3";
+  var VERSION = "2.4.0";
   
   var MML = MathJax.ElementJax.mml
       SETTINGS = MathJax.Hub.config.menuSettings;
@@ -38,10 +38,10 @@ MathJax.Hub.Register.LoadHook("[MathJax]/jax/element/mml/jax.js",function () {
       if (space == null) {space = ""}
       var tag = this.type, attr = this.toMathMLattributes();
       if (tag === "mspace") {return space + "<"+tag+attr+" />"}
-      var data = []; var SPACE = (this.isToken ? "" : space+(inferred ? "" : "  "));
+      var data = [], SPACE = (this.isToken ? "" : space+(inferred ? "" : "  "));
       for (var i = 0, m = this.data.length; i < m; i++) {
         if (this.data[i]) {data.push(this.data[i].toMathML(SPACE))}
-          else if (!this.isToken) {data.push(SPACE+"<mrow />")}
+          else if (!this.isToken && !this.isChars) {data.push(SPACE+"<mrow />")}
       }
       if (this.isToken) {return space + "<"+tag+attr+">"+data.join("")+"</"+tag+">"}
       if (inferred) {return data.join("\n")}
@@ -59,7 +59,7 @@ MathJax.Hub.Register.LoadHook("[MathJax]/jax/element/mml/jax.js",function () {
       if (!this.attrNames) {
         if (this.type === "mstyle") {defaults = MML.math.prototype.defaults}
         for (var id in defaults) {if (!skip[id] && defaults.hasOwnProperty(id)) {
-          var force = (id === "open" || id === "close");
+          var force = (id === "open" || id === "close" || id === "form");
           if (this[id] != null && (force || this[id] !== defaults[id])) {
             var value = this[id]; delete this[id];
             if (force || this.Get(id) !== value)
@@ -136,6 +136,38 @@ MathJax.Hub.Register.LoadHook("[MathJax]/jax/element/mml/jax.js",function () {
     }
   });
   
+  //
+  //  Override math.toMathML in order to add semantics tag
+  //  for the input format, if the user requests that in the
+  //  Show As menu.
+  //
+  MML.math.Augment({
+    toMathML: function (space,jax) {
+      var annotation;
+      if (space == null) {space = ""}
+      if (jax && jax.originalText && SETTINGS.semantics)
+        {annotation = MathJax.InputJax[jax.inputJax].annotationEncoding}
+      var nested = (this.data[0] && this.data[0].data.length > 1);
+      var tag = this.type, attr = this.toMathMLattributes();
+      var data = [], SPACE = space + (annotation ? "    " : "") + (nested ? "  " : "");
+      for (var i = 0, m = this.data.length; i < m; i++) {
+        if (this.data[i]) {data.push(this.data[i].toMathML(SPACE))}
+          else {data.push(SPACE+"<mrow />")}
+      }
+      if (data.length === 0 || (data.length === 1 && data[0] === "")) {
+        if (!annotation) {return "<"+tag+attr+" />"}
+        data.push(SPACE+"<mrow />");
+      }
+      if (annotation) {
+        if (nested) {data.unshift(space+"    <mrow>"); data.push(space+"    </mrow>")}
+        data.unshift(space+"  <semantics>");
+        data.push(space+'    <annotation encoding="'+annotation+'">'+jax.originalText+"</annotation>");
+        data.push(space+"  </semantics>");
+      }
+      return space+"<"+tag+attr+">\n"+data.join("\n")+"\n"+space+"</"+tag+">";
+    }
+  });
+  
   MML.msubsup.Augment({
     toMathML: function (space) {
       var tag = this.type;
