@@ -11,7 +11,7 @@
  *
  *  ---------------------------------------------------------------------
  *  
- *  Copyright (c) 2009-2013 The MathJax Consortium
+ *  Copyright (c) 2009-2014 The MathJax Consortium
  * 
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -30,7 +30,7 @@ MathJax.ElementJax.mml = MathJax.ElementJax({
   mimeType: "jax/mml"
 },{
   id: "mml",
-  version: "2.3",
+  version: "2.4.0",
   directory: MathJax.ElementJax.directory + "/mml",
   extensionDir: MathJax.ElementJax.extensionDir + "/mml",
   optableDir: MathJax.ElementJax.directory + "/mml/optable"
@@ -135,6 +135,7 @@ MathJax.ElementJax.mml.Augment({
     UPDIAGONALARROW: "updiagonalarrow",
     VERTICALSTRIKE: "verticalstrike",
     HORIZONTALSTRIKE: "horizontalstrike",
+    PHASORANGLE: "phasorangle",
     MADRUWB: "madruwb"
   },
   ALIGN: {
@@ -274,7 +275,7 @@ MathJax.ElementJax.mml.Augment({
     SetData: function (i,item) {
       if (item != null) {
         if (!(item instanceof MML.mbase))
-          {item = (this.isToken ? MML.chars(item) : MML.mtext(item))}
+          {item = (this.isToken || this.isChars ? MML.chars(item) : MML.mtext(item))}
         item.parent = this;
         item.setInherit(this.inheritFromMe ? this : this.inherit);
       }
@@ -517,7 +518,7 @@ MathJax.ElementJax.mml.Augment({
       lspace: MML.LENGTH.THICKMATHSPACE,
       rspace: MML.LENGTH.THICKMATHSPACE,
       stretchy: false,
-      symmetric: true,
+      symmetric: false,
       maxsize: MML.SIZE.INFINITY,
       minsize: '0em', //'1em',
       largeop: false,
@@ -600,12 +601,16 @@ MathJax.ElementJax.mml.Augment({
     isEmbellished: function () {return true},
     hasNewline: function () {return (this.Get("linebreak") === MML.LINEBREAK.NEWLINE)},
     setTeXclass: function (prev) {
-      this.getValues("lspace","rspace"); // sets useMMLspacing
+      var values = this.getValues("form","lspace","rspace","fence"); // sets useMMLspacing
       if (this.useMMLspacing) {this.texClass = MML.TEXCLASS.NONE; return this}
+      if (values.fence && !this.texClass) {
+        if (values.form === MML.FORM.PREFIX) {this.texClass = MML.TEXCLASS.OPEN}
+        if (values.form === MML.FORM.POSTFIX) {this.texClass = MML.TEXCLASS.CLOSE}
+      }
       this.texClass = this.Get("texClass");
       if (this.data.join("") === "\u2061") {
         // force previous node to be texClass OP, and skip this node
-        if (prev) prev.texClass = MML.TEXCLASS.OP;
+        if (prev) {prev.texClass = MML.TEXCLASS.OP; prev.fnOP = true}
         this.texClass = this.prevClass = MML.TEXCLASS.NONE;
         return prev;
       }
@@ -746,10 +751,27 @@ MathJax.ElementJax.mml.Augment({
       return this.SUPER(arguments).toString.call(this);
     },
     setTeXclass: function (prev) {
-      for (var i = 0, m = this.data.length; i < m; i++)
-        {if (this.data[i]) {prev = this.data[i].setTeXclass(prev)}}
-      if (this.data[0]) {this.updateTeXclass(this.data[0])}
-      return prev;
+      var i, m = this.data.length;
+      if ((this.open || this.close) && (!prev || !prev.fnOP)) {
+        //
+        // <mrow> came from \left...\right
+        // so treat as subexpression (tex class INNER)
+        //
+        this.getPrevClass(prev);
+        for (i = 0; i < m; i++)
+          {if (this.data[i]) {prev = this.data[i].setTeXclass(prev)}}
+        this.texClass = MML.TEXCLASS.INNER;
+        return this;
+      } else {
+        //
+        //  Normal <mrow>, so treat as
+        //  thorugh mrow is not there
+        //
+        for (i = 0; i < m; i++)
+          {if (this.data[i]) {prev = this.data[i].setTeXclass(prev)}}
+        if (this.data[0]) {this.updateTeXclass(this.data[0])}
+        return prev;
+      }
     },
     getAnnotation: function (name) {
       if (this.data.length != 1) return null;
@@ -907,7 +929,11 @@ MathJax.ElementJax.mml.Augment({
       values.separators = values.separators.replace(/[ \t\n\r]/g,"");
       // create a fake node for the open item
       if (values.open !== "") {
-        this.SetData("open",MML.mo(values.open).With({stretchy:true, texClass:MML.TEXCLASS.OPEN}));
+        this.SetData("open",MML.mo(values.open).With({
+          fence:true, form:MML.FORM.PREFIX, texClass:MML.TEXCLASS.OPEN
+        }));
+        //  Clear flag for using MML spacing even though form is specified
+        this.data.open.useMMLspacing &= ~this.data.open.SPACE_ATTR.form;
         prev = this.data.open.setTeXclass(prev);
       }
       // get the separators
@@ -921,7 +947,7 @@ MathJax.ElementJax.mml.Augment({
       for (var i = 1, m = this.data.length; i < m; i++) {
         if (this.data[i]) {
           if (values.separators !== "") {
-            this.SetData("sep"+i,MML.mo(values.separators.charAt(i-1)));
+            this.SetData("sep"+i,MML.mo(values.separators.charAt(i-1)).With({separator:true}));
             prev = this.data["sep"+i].setTeXclass(prev);
           }
           prev = this.data[i].setTeXclass(prev);
@@ -929,11 +955,16 @@ MathJax.ElementJax.mml.Augment({
       }
       // create fake node for the close item
       if (values.close !== "") {
-        this.SetData("close",MML.mo(values.close).With({stretchy:true, texClass:MML.TEXCLASS.CLOSE}));
+        this.SetData("close",MML.mo(values.close).With({
+          fence:true, form:MML.FORM.POSTFIX, texClass:MML.TEXCLASS.CLOSE
+        }));
+        //  Clear flag for using MML spacing even though form is specified
+        this.data.close.useMMLspacing &= ~this.data.close.SPACE_ATTR.form;
         prev = this.data.close.setTeXclass(prev);
       }
       // get the data from the open item
       this.updateTeXclass(this.data.open);
+      this.texClass = MML.TEXCLASS.INNER;
       return prev;
     }
   });
@@ -1216,7 +1247,7 @@ MathJax.ElementJax.mml.Augment({
     }
   });
   MML.annotation = MML.mbase.Subclass({
-    type: "annotation", isToken: true,
+    type: "annotation", isChars: true,
     linebreakContainer: true,
     defaults: {
       definitionURL: null,
@@ -1692,8 +1723,13 @@ MathJax.ElementJax.mml.Augment({
   //  These are not in the W3C table, but FF works this way,
   //  and it makes sense, so add it here
   //
-  MML.mo.prototype.OPTABLE.infix["^"] = MO.WIDEREL;
-  MML.mo.prototype.OPTABLE.infix["_"] = MO.WIDEREL;
+  var OPTABLE = MML.mo.prototype.OPTABLE;
+  OPTABLE.infix["^"] = MO.WIDEREL;
+  OPTABLE.infix["_"] = MO.WIDEREL;
+  OPTABLE.prefix["\u2223"] = MO.OPEN;
+  OPTABLE.prefix["\u2225"] = MO.OPEN;
+  OPTABLE.postfix["\u2223"] = MO.CLOSE;
+  OPTABLE.postfix["\u2225"] = MO.CLOSE;
   
 })(MathJax.ElementJax.mml);
 
