@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/es/HTML-CSS.js
  *
- *  Copyright (c) 2009-2013 The MathJax Consortium
+ *  Copyright (c) 2009-2014 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,10 +22,14 @@
  */
 
 MathJax.Localization.addTranslation("es","HTML-CSS",{
-        version: "2.3",
+        version: "2.4.0",
         isLoaded: true,
         strings: {
-
+          LoadWebFont: "Cargando el tipo de letra web %1",
+          CantLoadWebFont: "No se pudo cargar la fuente web %1",
+          FirefoxCantLoadWebFont: "Firefox no puede cargar tipos de letra web desde un equipo remoto",
+          CantFindFontUsing: "No se pudo encontrar una fuente v\u00E1lida usando %1",
+          WebFontsNotAvailable: "No hay fuentes web disponibles. Usando fuentes de imagen en su lugar"
         }
 });
 
