@@ -5,7 +5,7 @@
  *
  *  MathJax/localization/fr/MathML.js
  *
- *  Copyright (c) 2009-2013 The MathJax Consortium
+ *  Copyright (c) 2009-2014 The MathJax Consortium
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -22,12 +22,12 @@
  */
 
 MathJax.Localization.addTranslation("fr","MathML",{
-        version: "2.3",
+        version: "2.4.0",
         isLoaded: true,
         strings: {
           BadMglyph: "\u00C9lement mglyph incorrect: %1",
           BadMglyphFont: "Police non valide : %1",
-          MathPlayer: "MathJax n\u2019a pas pu configurer MathPlayer.\n\nSi MathPlayer n\u2019est pas install\u00E9, vous devez d\u2019abord le faire.\nSinon, il se peut que vos param\u00E8tres de s\u00E9curit\u00E9 emp\u00EAchent l\u2019ex\u00E9cution des contr\u00F4les ActiveX. Utilisez l\u2019entr\u00E9e Options Internet sous le menu Outils et s\u00E9lectionnez l\u2019onglet S\u00E9curit\u00E9, puis cliquez le bouton \u00AB Personnaliser le niveau \u00BB. V\u00E9rifiez que les param\u00E8tres pour 'Ex\u00E9cuter les contr\u00F4les ActiveX', et 'Comportement de fichiers binaires et des scripts' sont activ\u00E9s.\n\nPour le moment, vous verrez des messages d\u2019erreur au lieu de math\u00E9matiques compos\u00E9es.",
+          MathPlayer: "MathJax n\u2019a pas pu configurer MathPlayer.\n\nSi MathPlayer n\u2019est pas install\u00E9, vous devez d\u2019abord le faire.\nSinon, il se peut que vos param\u00E8tres de s\u00E9curit\u00E9 emp\u00EAchent l\u2019ex\u00E9cution des contr\u00F4les ActiveX. Utilisez l\u2019entr\u00E9e Options Internet sous le menu Outils et s\u00E9lectionnez l\u2019onglet S\u00E9curit\u00E9, puis cliquez le bouton \u00AB Personnaliser le niveau \u00BB. V\u00E9rifiez que les param\u00E8tres pour 'Ex\u00E9cuter les contr\u00F4les ActiveX', et 'Comportement de fichiers binaires et des scripts' sont activ\u00E9s.\n\nPour le moment, vous verrez des messages d\u2019erreur au lieu de textes math\u00E9matiques.",
           CantCreateXMLParser: "MathJax ne peut pas cr\u00E9er un analyseur XML pour MathML. V\u00E9rifiez que l\u2019option de s\u00E9curit\u00E9 'Contr\u00F4les ActiveX reconnus s\u00FBrs pour l\u2019\u00E9criture de scripts' est activ\u00E9e (utilisez l\u2019entr\u00E9e Options Internet dans le menu Outils, et s\u00E9lectionnez l\u2019onglet S\u00E9curit\u00E9, puis appuyez sur le bouton Personnaliser le niveau, pour le v\u00E9rifier).",
           UnknownNodeType: "Type de n\u0153ud inconnu : %1",
           UnexpectedTextNode: "N\u0153ud de texte inattendu : %1",
